#
# spec file for package openstack-freezer-api
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           openstack-freezer-api
Version:        7.0.1~dev46
Release:        1.5
Summary:        OpenStack Backup and Restore - API service
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/freezer
Source0:        freezer-api-master.tar.gz
Source1:        openstack-freezer-api.logrotate
BuildRequires:  openstack-macros
BuildRequires:  python-Paste
BuildRequires:  python-PasteDeploy
BuildRequires:  python-elasticsearch
BuildRequires:  python-falcon
BuildRequires:  python-fixtures
BuildRequires:  python-jsonschema
BuildRequires:  python-keystonemiddleware
BuildRequires:  python-mock
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.context
BuildRequires:  python-oslo.db
BuildRequires:  python-oslo.i18n
BuildRequires:  python-oslo.log
BuildRequires:  python-oslo.middleware
BuildRequires:  python-oslo.policy
BuildRequires:  python-oslo.upgradecheck
BuildRequires:  python-oslotest
BuildRequires:  python-reno
BuildRequires:  python-six
BuildRequires:  python-testrepository
BuildRequires:  python-testtools
Requires:       python-freezer-api = %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
Requires(pre):  pwdutils
%{?systemd_requires}
%endif
%if 0%{?rdo}
BuildRequires:  systemd
Requires(post): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils
Requires(preun): systemd
%endif

%description
API service for OpenStack Freeze: an OpenStack Swift incremental
backup and restore automation tool for file system, MongoDB,
MySQL. LVM snapshot and encryption support.

%package -n     python-freezer-api
Summary:        Freezer API Python library
Group:          Applications/System
Requires:       python-Paste
Requires:       python-PasteDeploy
Requires:       python-elasticsearch
Requires:       python-falcon
Requires:       python-jsonschema
Requires:       python-keystonemiddleware
Requires:       python-oslo.config
Requires:       python-oslo.context
Requires:       python-oslo.db
Requires:       python-oslo.i18n
Requires:       python-oslo.log
Requires:       python-oslo.middleware
Requires:       python-oslo.policy
Requires:       python-six

%description -n python-freezer-api
API service for OpenStack Freezer: an OpenStack Swift incremental
backup and restore automation tool for file system, MongoDB,
MySQL. LVM snapshot and encryption support.

This package contains the Freezer API python libraries.

%package doc
Summary:        Documentation for OpenStack Backup Service
Group:          Documentation/HTML
BuildRequires:  fdupes
BuildRequires:  python-Sphinx
#BuildRequires:  python-openstackdocstheme
BuildRequires:  python-os-api-ref
BuildRequires:  python-oslosphinx

%description doc
OpenStack Freezer API documentation.

This package contains the documentation

%prep
%autosetup -p1 -n freezer-api-7.0.1.dev46
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%{py2_build}

%{__python2} setup.py build_sphinx --builder=html,man
# remove the Sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}
%fdupes doc/build/html/

# config file generation
PYTHONPATH=. oslo-config-generator --config-file config-generator/freezer-api.conf \
    --output-file etc/freezer/freezer-api.conf.sample
# policy file generation
PYTHONPATH=. oslopolicy-sample-generator --config-file etc/freezer/freezer-policy-generator.conf \
    --output-file etc/freezer/freezer-api.policy.yaml

%install
%{py2_install}
install -d -m 755 %{buildroot}%{_sysconfdir}/freezer
install -d -m 755 %{buildroot}%{_sysconfdir}/freezer/freezer-api.conf.d/
install -d -m 755 %{buildroot}%{_localstatedir}/{lib,log}/freezer
install -p -D -m 640 etc/freezer/freezer-api.conf.sample %{buildroot}%{_sysconfdir}/freezer/freezer-api.conf
install -p -D -m 640 etc/freezer/freezer-api.policy.yaml %{buildroot}%{_sysconfdir}/freezer/policy.yaml
install -p -D -m 640 etc/freezer/freezer-paste.ini %{buildroot}%{_sysconfdir}/freezer/freezer-paste.ini
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-freezer-api

# remove duplicates
%fdupes %{buildroot}%{python2_sitelib}

%pre
%openstack_pre_user_group_create freezer freezer /sbin/nologin

%check
OS_PATH_TEST=./freezer_api/tests/unit python setup.py test

%files
%license LICENSE
%doc README.rst
%{_bindir}/freezer-api
%{_bindir}/freezer-api-wsgi
%{_bindir}/freezer-manage
%{_bindir}/freezer-manager-status
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/freezer-api.conf.d/
%config(noreplace) %attr(0640, root, freezer) %{_sysconfdir}/freezer/freezer-api.conf
%config(noreplace) %attr(0640, root, freezer) %{_sysconfdir}/freezer/freezer-paste.ini
%config(noreplace) %attr(0640, root, freezer) %{_sysconfdir}/freezer/policy.yaml
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-freezer-api
%dir %attr(0755, freezer, freezer) %{_localstatedir}/lib/freezer
%dir %attr(0750, freezer, freezer) %{_localstatedir}/log/freezer

%files -n python-freezer-api
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%{python2_sitelib}/freezer_api/
%{python2_sitelib}/freezer_api*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
